@@ -46,10 +46,10 @@ keys_near.tbl_ts <- function(.data,
       .vars = dplyr::vars( {{ var }} ),
       .funs = funs,
       ...) %>%
-    dplyr::select(key,
+    dplyr::select(dplyr::all_of(key),
                   {{ var }},
                   dplyr::any_of(names(funs))) %>%
-    tidyr::pivot_longer(cols = -c(key, {{ var }}),
+    tidyr::pivot_longer(cols = -c(dplyr::all_of(key), {{ var }}),
                         names_to = "stat",
                         values_to = "stat_value") %>% 
     dplyr::mutate(stat_diff = abs({{ var }} - stat_value)) %>%
