@@ -1,5 +1,3 @@
-context("test-sample-n-frac-obs")
-
 l_sample_n_keys <- sample_n_keys(.data = wages,
                                  size = 10)
 
@@ -27,8 +25,8 @@ test_that("correct names returned", {
 })
 
 test_that("Returns a tibble", {
-  expect_is(l_sample_n_keys, "tbl")
-  expect_is(l_sample_frac_keys, "tbl")
+  expect_s3_class(l_sample_n_keys, "tbl")
+  expect_s3_class(l_sample_frac_keys, "tbl")
 })
 
 classes <- function(x) purrr::map_chr(x, class)
